==> openshift-model-config-6.2.0-sources.jar: io/fabric8/openshift/api/model/config/v1/DeprecatedWebhookTokenAuthenticatorFluentImpl.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class DeprecatedWebhookTokenAuthenticatorFluentImpl<A extends DeprecatedWebhookTokenAuthenticatorFluent<A>> extends BaseFluent<A> implements DeprecatedWebhookTokenAuthenticatorFluent<A>{
  public DeprecatedWebhookTokenAuthenticatorFluentImpl() {
  }
  public DeprecatedWebhookTokenAuthenticatorFluentImpl(DeprecatedWebhookTokenAuthenticator instance) {
    this.withKubeConfig(instance.getKubeConfig()); 
    this.withAdditionalProperties(instance.getAdditionalProperties());

  }
  private SecretNameReferenceBuilder kubeConfig;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildKubeConfig instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretNameReference getKubeConfig() {
    return this.kubeConfig!=null ?this.kubeConfig.build():null;
  }
  public SecretNameReference buildKubeConfig() {
    return this.kubeConfig!=null ?this.kubeConfig.build():null;
  }
  public A withKubeConfig(SecretNameReference kubeConfig) {
    _visitables.get("kubeConfig").remove(this.kubeConfig);
    if (kubeConfig!=null){ this.kubeConfig= new SecretNameReferenceBuilder(kubeConfig); _visitables.get("kubeConfig").add(this.kubeConfig);} else { this.kubeConfig = null; _visitables.get("kubeConfig").remove(this.kubeConfig); } return (A) this;
  }
  public Boolean hasKubeConfig() {
    return this.kubeConfig != null;
  }
  public A withNewKubeConfig(String name) {
    return (A)withKubeConfig(new SecretNameReference(name));
  }
  public DeprecatedWebhookTokenAuthenticatorFluent.KubeConfigNested<A> withNewKubeConfig() {
    return new DeprecatedWebhookTokenAuthenticatorFluentImpl.KubeConfigNestedImpl();
  }
  public DeprecatedWebhookTokenAuthenticatorFluent.KubeConfigNested<A> withNewKubeConfigLike(SecretNameReference item) {
    return new DeprecatedWebhookTokenAuthenticatorFluentImpl.KubeConfigNestedImpl(item);
  }
  public DeprecatedWebhookTokenAuthenticatorFluent.KubeConfigNested<A> editKubeConfig() {
    return withNewKubeConfigLike(getKubeConfig());
  }
  public DeprecatedWebhookTokenAuthenticatorFluent.KubeConfigNested<A> editOrNewKubeConfig() {
    return withNewKubeConfigLike(getKubeConfig() != null ? getKubeConfig(): new SecretNameReferenceBuilder().build());
  }
  public DeprecatedWebhookTokenAuthenticatorFluent.KubeConfigNested<A> editOrNewKubeConfigLike(SecretNameReference item) {
    return withNewKubeConfigLike(getKubeConfig() != null ? getKubeConfig(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    DeprecatedWebhookTokenAuthenticatorFluentImpl that = (DeprecatedWebhookTokenAuthenticatorFluentImpl) o;
    if (kubeConfig != null ? !kubeConfig.equals(that.kubeConfig) :that.kubeConfig != null) return false;
    if (additionalProperties != null ? !additionalProperties.equals(that.additionalProperties) :that.additionalProperties != null) return false;
    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(kubeConfig,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (kubeConfig != null) { sb.append("kubeConfig:"); sb.append(kubeConfig + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class KubeConfigNestedImpl<N> extends SecretNameReferenceFluentImpl<DeprecatedWebhookTokenAuthenticatorFluent.KubeConfigNested<N>> implements DeprecatedWebhookTokenAuthenticatorFluent.KubeConfigNested<N>,Nested<N>{
    KubeConfigNestedImpl(SecretNameReference item) {
      this.builder = new SecretNameReferenceBuilder(this, item);
    }
    KubeConfigNestedImpl() {
      this.builder = new SecretNameReferenceBuilder(this);
    }
    SecretNameReferenceBuilder builder;
    public N and() {
      return (N) DeprecatedWebhookTokenAuthenticatorFluentImpl.this.withKubeConfig(builder.build());
    }
    public N endKubeConfig() {
      return and();
    }
    
  }
  
}

==> openshift-model-config-6.7.2-sources.jar: io/fabric8/openshift/api/model/config/v1/DeprecatedWebhookTokenAuthenticatorFluentImpl.java <==
package io.fabric8.openshift.api.model.config.v1;

import java.lang.SuppressWarnings;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.BaseFluent;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
  @SuppressWarnings(value = "unchecked")
  public class DeprecatedWebhookTokenAuthenticatorFluentImpl<A extends DeprecatedWebhookTokenAuthenticatorFluent<A>> extends BaseFluent<A> implements DeprecatedWebhookTokenAuthenticatorFluent<A>{
  public DeprecatedWebhookTokenAuthenticatorFluentImpl() {
  }
  public DeprecatedWebhookTokenAuthenticatorFluentImpl(DeprecatedWebhookTokenAuthenticator instance) {
    if (instance != null) {
      this.withKubeConfig(instance.getKubeConfig());
      this.withAdditionalProperties(instance.getAdditionalProperties());
    }
  }
  private SecretNameReferenceBuilder kubeConfig;
  private Map<String,Object> additionalProperties;
  
  /**
   * This method has been deprecated, please use method buildKubeConfig instead.
   * @return The buildable object.
   */
  @Deprecated
  public SecretNameReference getKubeConfig() {
    return this.kubeConfig!=null ?this.kubeConfig.build():null;
  }
  public SecretNameReference buildKubeConfig() {
    return this.kubeConfig!=null ?this.kubeConfig.build():null;
  }
  public A withKubeConfig(SecretNameReference kubeConfig) {
    _visitables.get("kubeConfig").remove(this.kubeConfig);
    if (kubeConfig!=null){ this.kubeConfig= new SecretNameReferenceBuilder(kubeConfig); _visitables.get("kubeConfig").add(this.kubeConfig);} else { this.kubeConfig = null; _visitables.get("kubeConfig").remove(this.kubeConfig); } return (A) this;
  }
  public Boolean hasKubeConfig() {
    return this.kubeConfig != null;
  }
  public A withNewKubeConfig(String name) {
    return (A)withKubeConfig(new SecretNameReference(name));
  }
  public DeprecatedWebhookTokenAuthenticatorFluentImpl.KubeConfigNested<A> withNewKubeConfig() {
    return new DeprecatedWebhookTokenAuthenticatorFluentImpl.KubeConfigNestedImpl();
  }
  public DeprecatedWebhookTokenAuthenticatorFluentImpl.KubeConfigNested<A> withNewKubeConfigLike(SecretNameReference item) {
    return new DeprecatedWebhookTokenAuthenticatorFluentImpl.KubeConfigNestedImpl(item);
  }
  public DeprecatedWebhookTokenAuthenticatorFluentImpl.KubeConfigNested<A> editKubeConfig() {
    return withNewKubeConfigLike(getKubeConfig());
  }
  public DeprecatedWebhookTokenAuthenticatorFluentImpl.KubeConfigNested<A> editOrNewKubeConfig() {
    return withNewKubeConfigLike(getKubeConfig() != null ? getKubeConfig(): new SecretNameReferenceBuilder().build());
  }
  public DeprecatedWebhookTokenAuthenticatorFluentImpl.KubeConfigNested<A> editOrNewKubeConfigLike(SecretNameReference item) {
    return withNewKubeConfigLike(getKubeConfig() != null ? getKubeConfig(): item);
  }
  public A addToAdditionalProperties(String key,Object value) {
    if(this.additionalProperties == null && key != null && value != null) { this.additionalProperties = new LinkedHashMap(); }
    if(key != null && value != null) {this.additionalProperties.put(key, value);} return (A)this;
  }
  public A addToAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null && map != null) { this.additionalProperties = new LinkedHashMap(); }
    if(map != null) { this.additionalProperties.putAll(map);} return (A)this;
  }
  public A removeFromAdditionalProperties(String key) {
    if(this.additionalProperties == null) { return (A) this; }
    if(key != null && this.additionalProperties != null) {this.additionalProperties.remove(key);} return (A)this;
  }
  public A removeFromAdditionalProperties(Map<String,Object> map) {
    if(this.additionalProperties == null) { return (A) this; }
    if(map != null) { for(Object key : map.keySet()) {if (this.additionalProperties != null){this.additionalProperties.remove(key);}}} return (A)this;
  }
  public Map<String,Object> getAdditionalProperties() {
    return this.additionalProperties;
  }
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties) {
    if (additionalProperties == null) { this.additionalProperties =  null;} else {this.additionalProperties = new LinkedHashMap(additionalProperties);} return (A) this;
  }
  public Boolean hasAdditionalProperties() {
    return this.additionalProperties != null;
  }
  public boolean equals(Object o) {
    if (this == o) return true;
    if (o == null || getClass() != o.getClass()) return false;
    if (!super.equals(o)) return false;
    DeprecatedWebhookTokenAuthenticatorFluentImpl that = (DeprecatedWebhookTokenAuthenticatorFluentImpl) o;
    if (!java.util.Objects.equals(kubeConfig, that.kubeConfig)) return false;

    if (!java.util.Objects.equals(additionalProperties, that.additionalProperties)) return false;

    return true;
  }
  public int hashCode() {
    return java.util.Objects.hash(kubeConfig,  additionalProperties,  super.hashCode());
  }
  public String toString() {
    StringBuilder sb = new StringBuilder();
    sb.append("{");
    if (kubeConfig != null) { sb.append("kubeConfig:"); sb.append(kubeConfig + ","); }
    if (additionalProperties != null && !additionalProperties.isEmpty()) { sb.append("additionalProperties:"); sb.append(additionalProperties); }
    sb.append("}");
    return sb.toString();
  }
  class KubeConfigNestedImpl<N> extends SecretNameReferenceFluentImpl<DeprecatedWebhookTokenAuthenticatorFluentImpl.KubeConfigNested<N>> implements DeprecatedWebhookTokenAuthenticatorFluentImpl.KubeConfigNested<N>,Nested<N>{
    KubeConfigNestedImpl(SecretNameReference item) {
      this.builder = new SecretNameReferenceBuilder(this, item);
    }
    KubeConfigNestedImpl() {
      this.builder = new SecretNameReferenceBuilder(this);
    }
    SecretNameReferenceBuilder builder;
    public N and() {
      return (N) DeprecatedWebhookTokenAuthenticatorFluentImpl.this.withKubeConfig(builder.build());
    }
    public N endKubeConfig() {
      return and();
    }
    
  }
  
}
